:github_url: {{ fullname }}

{{ fullname | escape | underline}}

.. autofunction:: {{ fullname }}

.. _sphx_glr_backref_{{fullname}}:

.. minigallery:: {{fullname}}
   :add-heading: Examples
   :heading-level: -
